@@ -4,12 +4,12 @@ pub mod prelude {
 
 pub use pixels;
 
-use bevy_app::prelude::*;
-use bevy_diagnostic::{Diagnostic, DiagnosticId, Diagnostics};
-use bevy_ecs::prelude::*;
-use bevy_window::prelude::*;
-use bevy_window::{WindowBackendScaleFactorChanged, WindowId, WindowResized};
-use bevy_winit::WinitWindows;
+use bevy::{
+    diagnostic::{Diagnostic, DiagnosticId, Diagnostics},
+    prelude::*,
+    window::{WindowBackendScaleFactorChanged, WindowId, WindowResized},
+    winit::WinitWindows,
+};
 use pixels::{Pixels, SurfaceTexture};
 use std::time::Instant;
 
@@ -45,7 +45,7 @@ pub struct PixelsResource {
 pub struct PixelsPlugin;
 
 impl Plugin for PixelsPlugin {
-    fn build(&self, app: &mut AppBuilder) {
+    fn build(&self, app: &mut App) {
         app.add_stage_after(
             CoreStage::PostUpdate,
             PixelsStage::Draw,
@@ -62,10 +62,10 @@ impl Plugin for PixelsPlugin {
             SystemStage::parallel(),
         )
         .init_resource::<PixelsOptions>()
-        .add_startup_system(Self::setup_system.system())
-        .add_system(Self::window_resize_system.system())
-        .add_system(Self::window_change_system.system())
-        .add_system_to_stage(PixelsStage::Render, Self::render_system.system());
+        .add_startup_system(Self::setup_system)
+        .add_system(Self::window_resize_system)
+        .add_system(Self::window_change_system)
+        .add_system_to_stage(PixelsStage::Render, Self::render_system);
     }
 }
 
